==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier.md <==
# AmazonSimpleStorageServiceS3Glacier


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')
```



| Illustration | AmazonSimpleStorageServiceS3Glacier | AmazonSimpleStorageServiceS3GlacierCard | AmazonSimpleStorageServiceS3GlacierGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier.png) | ![illustration for AmazonSimpleStorageServiceS3Glacier](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierGroup.Local.png) |




## AmazonSimpleStorageServiceS3Glacier

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Glacier
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3Glacier('AmazonSimpleStorageServiceS3Glacier', 'Amazon Simple Storage Service S3 Glacier', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Glacier
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3Glacier('AmazonSimpleStorageServiceS3Glacier', 'Amazon Simple Storage Service S3 Glacier', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierCard('AmazonSimpleStorageServiceS3GlacierCard', 'Amazon Simple Storage Service S3 Glacier Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierCard('AmazonSimpleStorageServiceS3GlacierCard', 'Amazon Simple Storage Service S3 Glacier Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierGroup('AmazonSimpleStorageServiceS3GlacierGroup', 'Amazon Simple Storage Service S3 Glacier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierGroup('AmazonSimpleStorageServiceS3GlacierGroup', 'Amazon Simple Storage Service S3 Glacier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier.md <==
# AmazonSimpleStorageServiceS3Glacier


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')
```



| Illustration | AmazonSimpleStorageServiceS3Glacier | AmazonSimpleStorageServiceS3GlacierCard | AmazonSimpleStorageServiceS3GlacierGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier.png) | ![illustration for AmazonSimpleStorageServiceS3Glacier](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierGroup.Local.png) |




## AmazonSimpleStorageServiceS3Glacier

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Glacier
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3Glacier('AmazonSimpleStorageServiceS3Glacier', 'Amazon Simple Storage Service S3 Glacier', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3Glacier
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3Glacier('AmazonSimpleStorageServiceS3Glacier', 'Amazon Simple Storage Service S3 Glacier', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierCard('AmazonSimpleStorageServiceS3GlacierCard', 'Amazon Simple Storage Service S3 Glacier Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierCard('AmazonSimpleStorageServiceS3GlacierCard', 'Amazon Simple Storage Service S3 Glacier Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierGroup('AmazonSimpleStorageServiceS3GlacierGroup', 'Amazon Simple Storage Service S3 Glacier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3Glacier')

' renders the element
AmazonSimpleStorageServiceS3GlacierGroup('AmazonSimpleStorageServiceS3GlacierGroup', 'Amazon Simple Storage Service S3 Glacier Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
